@@ -47,7 +47,6 @@ class cmd_base(argparse.ArgumentParser):
         res = {}
         res['help'] = args['help']
         default = args['default']
-        res['default'] = default
         if default is False:
             res['action'] = 'store_true'
             return res
@@ -56,10 +55,12 @@ class cmd_base(argparse.ArgumentParser):
             return res
         elif isinstance(default, int) or isinstance(default, str) or isinstance(default, float):
             res['action'] = 'store'
+            res['const'] = default
             res['nargs'] = '?'
             return res
         elif isinstance(default, list):
             res['action'] = 'extend'
+            res['const'] = default
             res['nargs'] = '*'
             return res
         else:
